
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/services', {
        apiVersion: 2,
        title: 'Services',
        icon: 'block-default',
        category: 'flex',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            section_id: {
                type: 'text',
                default: '',
            },
            label: {
                type: 'text',
                default: `Features`,
            },
            title: {
                type: 'text',
                default: `Gain more insight into how people use your`,
            },
            text: {
                type: 'text',
                default: `With our integrated CRM, project management, collaboration and invoicing capabilities, you can manage every aspect of your business in one secure platform.`,
            }
        },
        example: { attributes: { section_id: '', label: `Features`, title: `Gain more insight into how people use your`, text: `With our integrated CRM, project management, collaboration and invoicing capabilities, you can manage every aspect of your business in one secure platform.` } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'py-24 md:pb-32 bg-white', style: { backgroundPosition: 'center',backgroundImage: 'url(\'' + (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/pattern-white.svg\')' }, id: propOrDefault( props.attributes.section_id, 'section_id' ) });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = useInnerBlocksProps({ className: 'flex flex-wrap -mx-4' }, {
                allowedBlocks: [ 'flexwebsite/service' ],
                template: [
    [ 'flexwebsite/service', {} ],
    [ 'flexwebsite/service', {} ],
    [ 'flexwebsite/service', {} ],
    [ 'flexwebsite/service', {} ],
    [ 'flexwebsite/service', {} ],
    [ 'flexwebsite/service', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('section', { ...blockProps }, el('div', { className: 'container px-4 mx-auto' }, [el('div', { className: 'md:max-w-4xl mb-12 mx-auto text-center' }, [el(RichText, { tagName: 'span', className: 'inline-block py-px px-2 mb-4 text-xs leading-5 text-green-500 bg-green-100 font-medium uppercase rounded-full shadow-sm', value: propOrDefault( props.attributes.label, 'label' ), onChange: function(val) { setAttributes( {label: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'h1', className: 'font-bold leading-tight mb-4 text-3xl tracking-tighter md:leading-tight md:text-4xl', value: propOrDefault( props.attributes.title, 'title' ), onChange: function(val) { setAttributes( {title: val }) }, withoutInteractiveFormatting: true, allowedFormats: [] }), el(RichText, { tagName: 'p', className: 'text-lg md:text-xl text-coolGray-500 font-medium', value: propOrDefault( props.attributes.text, 'text' ), onChange: function(val) { setAttributes( {text: val }) } })]), el('div', { ...innerBlocksProps })])),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(TextControl, {
                                        value: props.attributes.section_id,
                                        help: __( '' ),
                                        label: __( 'Section id' ),
                                        onChange: function(val) { setAttributes({section_id: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.label,
                                        help: __( '' ),
                                        label: __( 'Section label' ),
                                        onChange: function(val) { setAttributes({label: val}) },
                                        type: 'text'
                                    }),
                                    el(TextControl, {
                                        value: props.attributes.title,
                                        help: __( '' ),
                                        label: __( 'Title' ),
                                        onChange: function(val) { setAttributes({title: val}) },
                                        type: 'text'
                                    }),
                                    el(BaseControl, {
                                        help: __( '' ),
                                        label: __( 'Text' ),
                                    }, [
                                        el(RichText, {
                                            value: props.attributes.text,
                                            style: {
                                                    border: '1px solid black',
                                                    padding: '6px 8px',
                                                    minHeight: '80px',
                                                    border: '1px solid rgb(117, 117, 117)',
                                                    fontSize: '13px',
                                                    lineHeight: 'normal'
                                                },
                                            onChange: function(val) { setAttributes({text: val}) },
                                        })
                                    ]),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'py-24 md:pb-32 bg-white', style: { backgroundPosition: 'center',backgroundImage: 'url(\'' + (pg_project_data_flexwebsite ? pg_project_data_flexwebsite.url : '') + 'images/pattern-white.svg\')' }, id: propOrDefault( props.attributes.section_id, 'section_id' ) });
            return el('section', { ...blockProps }, el('div', { className: 'container px-4 mx-auto' }, [el('div', { className: 'md:max-w-4xl mb-12 mx-auto text-center' }, [el(RichText.Content, { tagName: 'span', className: 'inline-block py-px px-2 mb-4 text-xs leading-5 text-green-500 bg-green-100 font-medium uppercase rounded-full shadow-sm', value: propOrDefault( props.attributes.label, 'label' ) }), el(RichText.Content, { tagName: 'h1', className: 'font-bold leading-tight mb-4 text-3xl tracking-tighter md:leading-tight md:text-4xl', value: propOrDefault( props.attributes.title, 'title' ) }), el(RichText.Content, { tagName: 'p', className: 'text-lg md:text-xl text-coolGray-500 font-medium', value: propOrDefault( props.attributes.text, 'text' ) })]), el('div', { className: 'flex flex-wrap -mx-4' }, el(InnerBlocks.Content, { allowedBlocks: [ 'flexwebsite/service' ] }))]));
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
