
( function ( blocks, element, blockEditor ) {
    const el = element.createElement,
        registerBlockType = blocks.registerBlockType,
        ServerSideRender = PgServerSideRender,
        InspectorControls = blockEditor.InspectorControls,
        useBlockProps = blockEditor.useBlockProps;
        
    const {__} = wp.i18n;
    const {ColorPicker, TextControl, ToggleControl, SelectControl, Panel, PanelBody, Disabled, TextareaControl, BaseControl} = wp.components;
    const {useSelect} = wp.data;
    const {RawHTML, Fragment} = element;
   
    const {InnerBlocks, URLInputButton, RichText} = wp.blockEditor;
    const useInnerBlocksProps = blockEditor.useInnerBlocksProps || blockEditor.__experimentalUseInnerBlocksProps;
    
    const propOrDefault = function(val, prop, field) {
        if(block.attributes[prop] && (val === null || val === '')) {
            return field ? block.attributes[prop].default[field] : block.attributes[prop].default;
        }
        return val;
    }
    
    const block = registerBlockType( 'flexwebsite/slider', {
        apiVersion: 2,
        title: 'Slider',
        icon: 'block-default',
        category: 'flex',
        keywords: [],
        supports: {color: {background: false,text: false,gradients: false,link: false,},typography: {fontSize: false,},anchor: false,align: false,},
        attributes: {
            show_prev_next: {
                type: 'text',
                default: '',
            }
        },
        example: { attributes: { show_prev_next: '' } },
        edit: function ( props ) {
            const blockProps = useBlockProps({ className: 'pgia-slider', 'data-pg-ia': '{"l":[{"trg":"now","a":{"l":[{"t":".pgia-slides-container #gt# .pgia-slide-#gt#first(${target.data-slider-slides-per-page|1})","l":[{"t":"set","p":0,"d":0,"s":0.1,"l":{"pgDom":{"clone":1,"ins":"append"}}}]}]},"pdef":"true","rstr":"true","name":"CloneSlidesForInfinite"},{"name":"AutoPlay","trg":"now","timer":"6","a":{"l":[{"t":"this","l":[{"t":"set","p":5.98,"d":0,"l":{"pgia":{"play":"GotoNext"}}}]},{"t":".pgia-progress-bar","l":[{"t":"set","p":0,"d":0,"l":{"width":0}},{"t":"tween","p":0,"d":5.98,"l":{"width":"100%"},"e":"Linear.easeNone"}]}]},"rpt":"-1","tcv":"slider-user-active","nopg":"true"},{"name":"UserActive","trg":"mouseenter","a":{"l":[{"t":"this","l":[{"t":"set","p":0,"d":0,"l":{"pgia":{"pause":"AutoPlay"}}}]},{"t":".pgia-progress","l":[{"t":"tween","p":0,"d":0.5,"l":{"autoAlpha":0}}]}]},"rstr":"true","po":"true","pol":"UserInactive"},{"name":"UserInactive","trg":"mouseleave_notouch","a":{"l":[{"t":"this","l":[{"t":"tween","p":0.5,"d":0.5,"l":{"pgia":{"play":"AutoPlay"}}}]},{"t":".pgia-progress","l":[{"t":"tween","p":0.5,"d":0.5,"l":{"autoAlpha":1}}]}]},"rstr":"true","po":"true","pol":"UserActive"},{"name":"SwipeLeftToNext","trg":"swipe_left","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoNext"}}}]}]},"tc":"no-attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"},{"name":"SwipeRightToPrev","trg":"swipe_right","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoPrev"}}}]}]},"tc":"no-attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"},{"name":"GotoNext","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"next_page_or_start"}}}]}]}},{"name":"GotoPrev","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"prev_page"}}}]}]}},{"name":"GotoFirst","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"first"}}}]}]}},{"name":"GotoLast","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"last"}}}]}]}},{"name":"SwipeDownToNext","trg":"swipe_down","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoNext"}}}]}]},"tc":"attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"},{"name":"SwipeUpToPrev","trg":"swipe_up","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoPrev"}}}]}]},"tc":"attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"}]}', 'data-slider-scrollbar': 'auto', 'data-slider-slides-per-page': '1', 'data-slider-direction': 'horizontal' });
            const setAttributes = props.setAttributes; 
            
            
            const innerBlocksProps = useInnerBlocksProps({ className: 'pgia-slides-container', 'data-pg-ia-scene': '{"s":"whole","snap":"e","pag":"p","pag_t":".pgia-slide","pag_i":"^.pgia-slider|.pgia-pagination-item","pag_clone":"true","pag_pa":"Current","pag_pd":"-Current","pag_inf":"true","dir":"a"}' }, {
                allowedBlocks: [ 'flexwebsite/slide' ],
                template: [
    [ 'flexwebsite/slide', {} ],
    [ 'flexwebsite/slide', {} ],
    [ 'flexwebsite/slide', {} ],
    [ 'flexwebsite/slide', {} ]
],
            } );
                            
            
            return el(Fragment, {}, [
                el('div', { ...blockProps }, [el('div', { ...innerBlocksProps }), el('div', { className: 'pgia-controls' }, [props.attributes.show_prev_next && el('a', { className: 'pgia-control prev', href: '#', 'data-scroll-to': 'prev', 'data-pg-ia': '{"l":[{"name":"ScrollTo","trg":"click","a":{"l":[{"t":"^.pgia-slider","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"Goto${target.data-scroll-to}"}}}]}]},"pdef":"true"}]}', 'data-pg-ia-apply': '^.pgia-slider|.pgia-control' }, '‹'), el('div', { className: 'pgia-pagination' }, el('a', { className: 'pgia-pagination-item', href: '#', 'data-pg-ia': '{"l":[{"name":"ScrollToSlide","trg":"click","a":{"l":[{"t":"^.pgia-slider|.pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"page"}}}]}]},"pdef":"true"},{"trg":"no","a":{"l":[{"t":"","l":[{"t":"tween","p":0,"d":0.2,"l":{"scale":1.3,"backgroundColor":"#2ad167"}}]}],"desc":"Customize the active item animation."},"name":"Current"}]}' })), props.attributes.show_prev_next && el('a', { className: 'next pgia-control', href: '#', 'data-scroll-to': 'next' }, '›')]), el('div', { className: 'pgia-progress' }, el('div', { className: 'pgia-progress-bar' }))]),                        
                
                    el( InspectorControls, {},
                        [
                            
                            el(Panel, {},
                                el(PanelBody, {
                                    title: __('Block properties')
                                }, [
                                    
                                    el(ToggleControl, {
                                        checked: props.attributes.show_prev_next === '1',
                                        label: __( 'Show Prev and Next buttons' ),
                                        onChange: function(val) { setAttributes({show_prev_next: val ? '1' : null}) },
                                        help: __( '' ),
                                    }),    
                                ])
                            )
                        ]
                    )                            

            ]);
        },

        save: function(props) {
            const blockProps = useBlockProps.save({ className: 'pgia-slider', 'data-pg-ia': '{"l":[{"trg":"now","a":{"l":[{"t":".pgia-slides-container #gt# .pgia-slide-#gt#first(${target.data-slider-slides-per-page|1})","l":[{"t":"set","p":0,"d":0,"s":0.1,"l":{"pgDom":{"clone":1,"ins":"append"}}}]}]},"pdef":"true","rstr":"true","name":"CloneSlidesForInfinite"},{"name":"AutoPlay","trg":"now","timer":"6","a":{"l":[{"t":"this","l":[{"t":"set","p":5.98,"d":0,"l":{"pgia":{"play":"GotoNext"}}}]},{"t":".pgia-progress-bar","l":[{"t":"set","p":0,"d":0,"l":{"width":0}},{"t":"tween","p":0,"d":5.98,"l":{"width":"100%"},"e":"Linear.easeNone"}]}]},"rpt":"-1","tcv":"slider-user-active","nopg":"true"},{"name":"UserActive","trg":"mouseenter","a":{"l":[{"t":"this","l":[{"t":"set","p":0,"d":0,"l":{"pgia":{"pause":"AutoPlay"}}}]},{"t":".pgia-progress","l":[{"t":"tween","p":0,"d":0.5,"l":{"autoAlpha":0}}]}]},"rstr":"true","po":"true","pol":"UserInactive"},{"name":"UserInactive","trg":"mouseleave_notouch","a":{"l":[{"t":"this","l":[{"t":"tween","p":0.5,"d":0.5,"l":{"pgia":{"play":"AutoPlay"}}}]},{"t":".pgia-progress","l":[{"t":"tween","p":0.5,"d":0.5,"l":{"autoAlpha":1}}]}]},"rstr":"true","po":"true","pol":"UserActive"},{"name":"SwipeLeftToNext","trg":"swipe_left","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoNext"}}}]}]},"tc":"no-attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"},{"name":"SwipeRightToPrev","trg":"swipe_right","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoPrev"}}}]}]},"tc":"no-attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"},{"name":"GotoNext","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"next_page_or_start"}}}]}]}},{"name":"GotoPrev","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"prev_page"}}}]}]}},{"name":"GotoFirst","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"first"}}}]}]}},{"name":"GotoLast","trg":"no","a":{"l":[{"t":".pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"last"}}}]}]}},{"name":"SwipeDownToNext","trg":"swipe_down","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoNext"}}}]}]},"tc":"attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"},{"name":"SwipeUpToPrev","trg":"swipe_up","a":{"l":[{"t":"this","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"GotoPrev"}}}]}]},"tc":"attr","tca":"data-slider-direction","tcv":"vertical","pdef":"true"}]}', 'data-slider-scrollbar': 'auto', 'data-slider-slides-per-page': '1', 'data-slider-direction': 'horizontal' });
            return el('div', { ...blockProps }, [el('div', { className: 'pgia-slides-container', 'data-pg-ia-scene': '{"s":"whole","snap":"e","pag":"p","pag_t":".pgia-slide","pag_i":"^.pgia-slider|.pgia-pagination-item","pag_clone":"true","pag_pa":"Current","pag_pd":"-Current","pag_inf":"true","dir":"a"}' }, el(InnerBlocks.Content, { allowedBlocks: [ 'flexwebsite/slide' ] })), el('div', { className: 'pgia-controls' }, [props.attributes.show_prev_next && el('a', { className: 'pgia-control prev', href: '#', 'data-scroll-to': 'prev', 'data-pg-ia': '{"l":[{"name":"ScrollTo","trg":"click","a":{"l":[{"t":"^.pgia-slider","l":[{"t":"tween","p":0,"d":0.5,"l":{"pgia":{"play":"Goto${target.data-scroll-to}"}}}]}]},"pdef":"true"}]}', 'data-pg-ia-apply': '^.pgia-slider|.pgia-control' }, '‹'), el('div', { className: 'pgia-pagination' }, el('a', { className: 'pgia-pagination-item', href: '#', 'data-pg-ia': '{"l":[{"name":"ScrollToSlide","trg":"click","a":{"l":[{"t":"^.pgia-slider|.pgia-slides-container","l":[{"t":"tween","p":0,"d":0.5,"l":{"scrollTo":{"dest":"page"}}}]}]},"pdef":"true"},{"trg":"no","a":{"l":[{"t":"","l":[{"t":"tween","p":0,"d":0.2,"l":{"scale":1.3,"backgroundColor":"#2ad167"}}]}],"desc":"Customize the active item animation."},"name":"Current"}]}' })), props.attributes.show_prev_next && el('a', { className: 'next pgia-control', href: '#', 'data-scroll-to': 'next' }, '›')]), el('div', { className: 'pgia-progress' }, el('div', { className: 'pgia-progress-bar' }))]);
        }                        

    } );
} )(
    window.wp.blocks,
    window.wp.element,
    window.wp.blockEditor
);                        
